#
# This file is part of Efforia project.
#
# Copyright (C) 2011-2013 William Oliveira de Lagos <william@efforia.com.br>
#
# Efforia is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Efforia is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Efforia. If not, see <http://www.gnu.org/licenses/>.
#

from django.conf.urls import patterns,url,include

urlpatterns = patterns('shipping.views')


#!/usr/bin/python
# -*- coding: utf-8 -*-

from urllib2 import Request,urlopen
from xml.dom import minidom as dom

class FreteFacilShippingService:
	def create_deliverable(self,sender,receiver,width,height,length,weight):
		if int(height) < 2: return 'Altura abaixo do mínimo (2cm).'
		if int(width) < 11: return 'Largura abaixo do mínimo (11cm).'
		if int(length) < 16: return 'Profundidade abaixo do mínimo (16cm).'
		deliverable = {
			'sender': sender,
			'receiver': receiver,
			'width': str(width),
			'height': str(height),
			'length': str(length),
			'weight': str(weight),
		}	
		return deliverable

	def build_request(self,d):
		url = 'https://ff.paypal-brasil.com.br/FretesPayPalWS/WSFretesPayPal'
		headers = {
			'Content-Type': 'text/xml; charset=utf-8',
			'SoapAction': '%s/getPreco' % url
		}
		xml = """<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\" xmlns:shipping=\"https://ff.paypal-brasil.com.br/FretesPayPalWS\">
	        <soapenv:Header />
	          <soapenv:Body>
	            <shipping:getPreco>
	              <cepOrigem>%s</cepOrigem>
	              <cepDestino>%s</cepDestino>
	              <largura>%s</largura>
	              <altura>%s</altura>
	              <profundidade>%s</profundidade>
	              <peso>%s</peso>
	            </shipping:getPreco>
	          </soapenv:Body>
	        </soapenv:Envelope>""" % (d['sender'],d['receiver'],d['width'],d['height'],d['length'],d['weight'])
		return url,headers,xml

	def delivery_value(self,deliverable):
		url,headers,xml = self.build_request(deliverable)
		req = Request(url,xml,headers)
		value = urlopen(req).read()
		val = dom.parseString(value).getElementsByTagName('return')[0].childNodes[0].wholeText
		if '-2.0' in val: return 'Não foi possível calcular o frete.'
		else: return '%.2f' % float(val)


#!/usr/bin/python
# -*- coding: utf-8 -*-

from django.utils.translation import ugettext as _

try:
    from mezzanine.conf import settings
    from cartridge.shop.utils import set_shipping
    from cartridge.shop.models import Cart
except ImportError,e:
    pass

from shipping.fretefacil import FreteFacilShippingService
from shipping.models import DeliverableProperty

def fretefacil_shipping_handler(request, order_form):
    if request.session.get("free_shipping"): return
    settings.use_editable()
    shippingservice = FreteFacilShippingService()
    cart = Cart.objects.from_request(request)
    delivery_value = 0.0
    if cart.has_items():
        for product in cart:
            print DeliverableProperty.objects.values()
            properties = DeliverableProperty.objects.filter(sku=product.sku)
            print properties
            if len(properties) > 0:
                props = properties[0]
                deliverable = shippingservice.create_deliverable(settings.STORE_POSTCODE,
                                                                 props.postcode,
                                                                 props.width,
                                                                 props.height,
                                                                 props.length,
                                                                 props.weight)
                delivery_value += float(shippingservice.delivery_value(deliverable))
    set_shipping(request, _("PayPal Frete Fácil"),delivery_value)